@@ -286,7 +286,11 @@ if CONFIG["CIRCE_ENABLE_WEB_UI"]:
             handler: logging.FileHandler = logging.FileHandler(
                 "{}/out.log".format(session_dir)
             )
-            handler.setFormatter(jsonlogger.JsonFormatter())
+            handler.setFormatter(
+                tasks.CustomJsonFormatter(
+                    "%(timestamp)s %(level)s %(name)s %(message)s"
+                )
+            )
             logger: logging.Logger = logging.Logger("job_logger_{}".format(session_id))
             logger.setLevel(logging.DEBUG)
             logger.addHandler(handler)
