@@ -26,6 +26,19 @@ def _stamp():
 registered_transfos = {}
 
 
+class CustomJsonFormatter(jsonlogger.JsonFormatter):
+    def add_fields(self, log_record, record, message_dict):
+        super(CustomJsonFormatter, self).add_fields(log_record, record, message_dict)
+        if not log_record.get("timestamp"):
+            # this doesn't use record.created, so it is slightly off
+            now = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+            log_record["timestamp"] = now
+        if log_record.get("level"):
+            log_record["level"] = log_record["level"].upper()
+        else:
+            log_record["level"] = record.levelname
+
+
 if CONFIG["CIRCE_TRANSFORMATIONS_MODULE"]:
     transformations_module = __import__(CONFIG["CIRCE_TRANSFORMATIONS_MODULE"])
     for transformation_name, _ in getmembers(transformations_module):
@@ -91,7 +104,9 @@ def do_transformations(uuid: uuid4, job_archive_path: str):
     with tempfile.TemporaryDirectory() as tmp_dir:
 
         handler: logging.FileHandler = logging.FileHandler("{}/out.log".format(tmp_dir))
-        handler.setFormatter(jsonlogger.JsonFormatter())
+        handler.setFormatter(
+            CustomJsonFormatter("%(timestamp)s %(level)s %(name)s %(message)s")
+        )
         logger: logging.Logger = logging.Logger("job_logger_{}".format(uuid.hex))
         logger.setLevel(logging.DEBUG)
         logger.addHandler(handler)
